@@ -18,7 +18,7 @@ class RbParser(sgmllib.SGMLParser):
 	
 	def start_div(self, attrs):
 		for attr in attrs:
-			if attr[0].lower()=='class' and attr[1].lower()=='normal-p0':
+			if attr[0].lower()=='class' and attr[1].lower().find('normal')!=-1:
 				self.in_day=True
 				self.day_text=[]
 		
@@ -68,7 +68,7 @@ def getSpecial():
       if str(div[0]) == str(time.localtime()[2]):
     	result = ""
       	for idx in range(1,len(div)):
-      	  result = result + str(div[idx]).strip()
+      	  result = result + str(div[idx]).strip() + " "
     	return result
     	found_special=True
 
@@ -83,4 +83,4 @@ def get():
         print """Today's special is %s""" % (special)
 
 if __name__ == "__main__":
-    show()
+    get()
